jenkins-bot has submitted this change and it was merged.

Change subject: Spell removable and movable using modern English
......................................................................


Spell removable and movable using modern English

Also...

* Make adders in outline controls always visible

Change-Id: I0a1bc2cdd0789fc3aa3304ca4c59347568302423
---
M src/layouts/OO.ui.BookletLayout.js
M src/styles/OO.ui.Widget.css
M src/widgets/OO.ui.OutlineControlsWidget.js
M src/widgets/OO.ui.OutlineItemWidget.js
4 files changed, 19 insertions(+), 22 deletions(-)

Approvals:
  Catrope: Looks good to me, approved
  jenkins-bot: Verified



diff --git a/src/layouts/OO.ui.BookletLayout.js 
b/src/layouts/OO.ui.BookletLayout.js
index 5e29ea9..6a2e0d1 100644
--- a/src/layouts/OO.ui.BookletLayout.js
+++ b/src/layouts/OO.ui.BookletLayout.js
@@ -268,7 +268,7 @@
                                        'label': page.getLabel() || name,
                                        'level': page.getLevel(),
                                        'icon': page.getIcon(),
-                                       'moveable': page.isMovable()
+                                       'movable': page.isMovable()
                                } )
                        );
                }
diff --git a/src/styles/OO.ui.Widget.css b/src/styles/OO.ui.Widget.css
index 2114d10..4aa8b4f 100644
--- a/src/styles/OO.ui.Widget.css
+++ b/src/styles/OO.ui.Widget.css
@@ -310,11 +310,8 @@
        float: right;
 }
 
-.oo-ui-outlineControlsWidget-adders:not(:hover) 
.oo-ui-iconButtonWidget:not(:first-child) {
-       opacity: 0;
-}
-
-.oo-ui-outlineControlsWidget-adders:hover .oo-ui-iconButtonWidget:first-child {
+.oo-ui-outlineControlsWidget-adders .oo-ui-iconButtonWidget:first-child,
+.oo-ui-outlineControlsWidget-adders .oo-ui-iconButtonWidget:first-child:hover {
        opacity: 0.25;
        cursor: default;
 }
diff --git a/src/widgets/OO.ui.OutlineControlsWidget.js 
b/src/widgets/OO.ui.OutlineControlsWidget.js
index 44f8f53..5299ee2 100644
--- a/src/widgets/OO.ui.OutlineControlsWidget.js
+++ b/src/widgets/OO.ui.OutlineControlsWidget.js
@@ -69,31 +69,31 @@
  * @method
  */
 OO.ui.OutlineControlsWidget.prototype.onOutlineChange = function () {
-       var i, len, firstMoveable, lastMoveable,
-               moveable = false,
+       var i, len, firstMovable, lastMovable,
+               movable = false,
                items = this.outline.getItems(),
                selectedItem = this.outline.getSelectedItem();
 
-       if ( selectedItem && selectedItem.isMoveable() ) {
-               moveable = true;
+       if ( selectedItem && selectedItem.isMovable() ) {
+               movable = true;
                i = -1;
                len = items.length;
                while ( ++i < len ) {
-                       if ( items[i].isMoveable() ) {
-                               firstMoveable = items[i];
+                       if ( items[i].isMovable() ) {
+                               firstMovable = items[i];
                                break;
                        }
                }
                i = len;
                while ( i-- ) {
-                       if ( items[i].isMoveable() ) {
-                               lastMoveable = items[i];
+                       if ( items[i].isMovable() ) {
+                               lastMovable = items[i];
                                break;
                        }
                }
        }
-       this.upButton.setDisabled( !moveable || selectedItem === firstMoveable 
);
-       this.downButton.setDisabled( !moveable || selectedItem === lastMoveable 
);
+       this.upButton.setDisabled( !movable || selectedItem === firstMovable );
+       this.downButton.setDisabled( !movable || selectedItem === lastMovable );
 };
 
 /**
diff --git a/src/widgets/OO.ui.OutlineItemWidget.js 
b/src/widgets/OO.ui.OutlineItemWidget.js
index 38fb723..637c21f 100644
--- a/src/widgets/OO.ui.OutlineItemWidget.js
+++ b/src/widgets/OO.ui.OutlineItemWidget.js
@@ -8,7 +8,7 @@
  * @param {Mixed} data Item data
  * @param {Object} [config] Configuration options
  * @cfg {number} [level] Indentation level
  * @cfg {boolean} [moveable] Allow modification from outline controls
  */
 OO.ui.OutlineItemWidget = function OoUiOutlineItemWidget( data, config ) {
        // Config intialization
@@ -19,7 +19,7 @@
 
        // Properties
        this.level = 0;
-       this.moveable = !!config.moveable;
+       this.movable = !!config.movable;
 
        // Initialization
        this.$element.addClass( 'oo-ui-outlineItemWidget' );
@@ -43,14 +43,14 @@
 /* Methods */
 
 /**
  * Check if item is moveable.
  *
  * Moveablilty is used by outline controls.
  *
  * @returns {boolean} Item is moveable
  */
-OO.ui.OutlineItemWidget.prototype.isMoveable = function () {
-       return this.moveable;
+OO.ui.OutlineItemWidget.prototype.isMovable = function () {
+       return this.movable;
 };
 
 /**
@@ -8,7 +8,7 @@
  * @param {Object} [config] Configuration options
  * @cfg {number} [level] Indentation level
- * @cfg {boolean} [moveable] Allow modification from outline controls
+ * @cfg {boolean} [movable] Allow modification from outline controls
  */
 OO.ui.OutlineItemWidget = function OoUiOutlineItemWidget( data, config ) {
@@ -43,14 +43,14 @@
 
 /**
- * Check if item is moveable.
+ * Check if item is movable.
  *
  * Moveablilty is used by outline controls.
@@ -43,14 +43,14 @@
  * Moveablilty is used by outline controls.
  *
- * @returns {boolean} Item is moveable
+ * @returns {boolean} Item is movable
  */

-- 
To view, visit https://gerrit.wikimedia.org/r/99723
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: merged
Gerrit-Change-Id: I0a1bc2cdd0789fc3aa3304ca4c59347568302423
Gerrit-PatchSet: 1
Gerrit-Project: oojs/ui
Gerrit-Branch: master
Gerrit-Owner: Trevor Parscal <[email protected]>
Gerrit-Reviewer: Catrope <[email protected]>
Gerrit-Reviewer: jenkins-bot

_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to